@@ -233,6 +233,13 @@ class Expression:
         return new_node
 
 
+class Annotation(Expression):
+    arg_types = {
+        "this": True,
+        "expression": True,
+    }
+
+
 class Cache(Expression):
     arg_types = {
         "this": True,
@@ -522,7 +529,11 @@ class Boolean(Expression):
 
 
 class DataType(Expression):
-    arg_types = {"this": True, "expressions": False}
+    arg_types = {
+        "this": True,
+        "expressions": False,
+        "nested": True,
+    }
 
     class Type(AutoName):
         CHAR = auto()
