@@ -206,6 +206,9 @@ class Generator:
 
         raise ValueError(f"Unsupported expression type {expression.__class__.__name__}")
 
+    def annotation_sql(self, expression):
+        return self.sql(expression, "expression")
+
     def uncache_sql(self, expression):
         table = self.sql(expression, "this")
         exists_sql = " IF EXISTS" if expression.args.get("exists") else ""
@@ -305,9 +308,11 @@ class Generator:
     def datatype_sql(self, expression):
         type_value = expression.this
         type_sql = self.type_mapping.get(type_value, type_value.value)
-        args = self.expressions(expression, flat=True)
-        args = f"({args})" if args else ""
-        return f"{type_sql}{args}"
+        nested = ""
+        interior = self.expressions(expression, flat=True)
+        if interior:
+            nested = f"<{interior}>" if expression.args["nested"] else f"({interior})"
+        return f"{type_sql}{nested}"
 
     def delete_sql(self, expression):
         this = self.sql(expression, "this")
