@@ -673,7 +673,9 @@ class Parser:
                 exp.Select,
                 hint=self._parse_hint(),
                 distinct=self._match(TokenType.DISTINCT),
-                expressions=self._parse_csv(self._parse_expression),
+                expressions=self._parse_csv(
+                    lambda: self._parse_annotation(self._parse_expression())
+                ),
                 **{
                     "from": this or self._parse_from(),
                     "laterals": self._parse_laterals(),
@@ -689,6 +691,14 @@ class Parser:
 
         return self._parse_set_operations(this)
 
+    def _parse_annotation(self, expression):
+        if self._match(TokenType.ANNOTATION):
+            return self.expression(
+                exp.Annotation, this=self._prev.text, expression=expression
+            )
+
+        return expression
+
     def _parse_hint(self):
         if self._match(TokenType.HINT):
             hints = self._parse_csv(self._parse_function)
@@ -1069,15 +1079,20 @@ class Parser:
             self._match(TokenType.ZONE)
             if tz:
                 return exp.DataType(
-                    this=exp.DataType.Type.TIMESTAMPTZ, expressions=expressions
+                    this=exp.DataType.Type.TIMESTAMPTZ,
+                    expressions=expressions,
+                    nested=nested,
                 )
             return exp.DataType(
-                this=exp.DataType.Type.TIMESTAMP, expressions=expressions
+                this=exp.DataType.Type.TIMESTAMP,
+                expressions=expressions,
+                nested=nested,
             )
 
         return exp.DataType(
             this=exp.DataType.Type[type_token.value.upper()],
             expressions=expressions,
+            nested=nested,
         )
 
     def _parse_column(self):
